@@ -35,8 +35,8 @@ def Improper_Same_Force(cls, atom_list):
             temp.append(atom_permutation)
     return temp
 
-@Molecule.Set_Save_SPONGE_Input
-def write_dihedral(self, prefix, dirname):
+@Molecule.Set_Save_SPONGE_Input("dihedral")
+def write_dihedral(self):
     dihedrals = []
     for dihedral in self.bonded_forces.get("dihedral", []):
         order = list(range(4))
@@ -49,7 +49,7 @@ def write_dihedral(self, prefix, dirname):
                 dihedrals.append("%d %d %d %d %d %f %f"%(self.atom_index[dihedral.atoms[temp_order[0]]]
                 , self.atom_index[dihedral.atoms[temp_order[1]]], self.atom_index[dihedral.atoms[temp_order[2]]]
                 , self.atom_index[dihedral.atoms[temp_order[3]]], dihedral.periodicitys[i], dihedral.ks[i], dihedral.phi0s[i]))
- 
+                
     for dihedral in self.bonded_forces.get("improper", []):
         order = list(range(4))
         if dihedral.k != 0:
@@ -67,6 +67,4 @@ def write_dihedral(self, prefix, dirname):
         dihedrals.sort(key = lambda x: list(map(float, x.split())))
         towrite += "\n".join(dihedrals)
         
-        f = open(os.path.join(dirname, prefix + "_dihedral.txt"),"w")
-        f.write(towrite)
-        f.close()
\ No newline at end of file
+        return towrite
\ No newline at end of file
